pub struct MatchFailure {
pub failed_at: usize,
pub expected_next: Vec<String>,
pub found: Option<String>,
}Expand description
Match failure: the observed sequence does not satisfy the
expression. failed_at is the index into the observed sequence
(== its length when the body ended too early); expected_next
lists the display forms of the terminals legal at that position;
found is the display form of the offending block (None at
end-of-body).
Fields
failed_at: usizeexpected_next: Vec<String>found: Option<String>Trait Implementations
Sourceimpl Clone for MatchFailure
impl Clone for MatchFailure
Sourcefn clone(&self) -> MatchFailure
fn clone(&self) -> MatchFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchFailure
impl Debug for MatchFailure
impl Eq for MatchFailure
Sourceimpl PartialEq for MatchFailure
impl PartialEq for MatchFailure
Sourceimpl Serialize for MatchFailure
impl Serialize for MatchFailure
impl StructuralPartialEq for MatchFailure