pub struct CommunityConfig {
pub resolution: f64,
pub seed: u32,
}Expand description
Community-detection (Louvain) defaults — schema-level, not per-type.
Distinct from the legacy schemas::CommunityConfig which was attached to
each TypeDefinition; the legacy variant has been removed.
Fields
resolution: f64seed: u32Trait Implementations
Sourceimpl Clone for CommunityConfig
impl Clone for CommunityConfig
Sourcefn clone(&self) -> CommunityConfig
fn clone(&self) -> CommunityConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommunityConfig
impl Debug for CommunityConfig
Sourceimpl<'de> Deserialize<'de> for CommunityConfig
impl<'de> Deserialize<'de> for CommunityConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommunityConfig
impl JsonSchema for CommunityConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommunityConfig
impl RefUnwindSafe for CommunityConfig
impl Send for CommunityConfig
impl Sync for CommunityConfig
impl Unpin for CommunityConfig
impl UnsafeUnpin for CommunityConfig
impl UnwindSafe for CommunityConfig