pub struct SignalThreshold {
pub at_least: u64,
pub level: SignalLevel,
}Expand description
One threshold step of a signal declaration.
Fields
at_least: u64level: SignalLevelTrait Implementations
Sourceimpl Clone for SignalThreshold
impl Clone for SignalThreshold
Sourcefn clone(&self) -> SignalThreshold
fn clone(&self) -> SignalThreshold
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SignalThreshold
Sourceimpl Debug for SignalThreshold
impl Debug for SignalThreshold
Sourceimpl<'de> Deserialize<'de> for SignalThreshold
impl<'de> Deserialize<'de> for SignalThreshold
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SignalThreshold
Sourceimpl JsonSchema for SignalThreshold
impl JsonSchema for SignalThreshold
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SignalThreshold
impl PartialEq for SignalThreshold
Sourceimpl Serialize for SignalThreshold
impl Serialize for SignalThreshold
impl StructuralPartialEq for SignalThreshold