pub struct TypeExample {
pub title: String,
pub sections: IndexMap<String, String>,
}Expand description
Inline few-shot example — concrete entity content matching this type.
Fields
title: Stringsections: IndexMap<String, String>Trait Implementations
Sourceimpl Clone for TypeExample
impl Clone for TypeExample
Sourcefn clone(&self) -> TypeExample
fn clone(&self) -> TypeExample
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeExample
impl Debug for TypeExample
Sourceimpl<'de> Deserialize<'de> for TypeExample
impl<'de> Deserialize<'de> for TypeExample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TypeExample
impl JsonSchema for TypeExample
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TypeExample
impl RefUnwindSafe for TypeExample
impl Send for TypeExample
impl Sync for TypeExample
impl Unpin for TypeExample
impl UnsafeUnpin for TypeExample
impl UnwindSafe for TypeExample