pub struct MetadataFieldDef {
pub key: String,
pub description: String,
pub field_type: FieldType,
pub default_value: Option<String>,
pub enum_values: Option<Vec<String>>,
pub optional: bool,
pub init_timestamp: bool,
pub auto_timestamp: bool,
pub serialization: Serialization,
pub filterable: Filterable,
}Expand description
A metadata (frontmatter) field.
Fields
key: Stringdescription: Stringfield_type: FieldTypedefault_value: Option<String>enum_values: Option<Vec<String>>optional: boolinit_timestamp: boolauto_timestamp: boolserialization: Serializationfilterable: FilterableTrait Implementations
Sourceimpl Clone for MetadataFieldDef
impl Clone for MetadataFieldDef
Sourcefn clone(&self) -> MetadataFieldDef
fn clone(&self) -> MetadataFieldDef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataFieldDef
impl Debug for MetadataFieldDef
Sourceimpl<'de> Deserialize<'de> for MetadataFieldDef
impl<'de> Deserialize<'de> for MetadataFieldDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetadataFieldDef
impl JsonSchema for MetadataFieldDef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MetadataFieldDef
impl RefUnwindSafe for MetadataFieldDef
impl Send for MetadataFieldDef
impl Sync for MetadataFieldDef
impl Unpin for MetadataFieldDef
impl UnsafeUnpin for MetadataFieldDef
impl UnwindSafe for MetadataFieldDef