pub struct SectionDef {
pub key: String,
pub heading: String,
pub required: bool,
pub search_weight: f32,
pub catch_all: bool,
pub write_rules: Vec<String>,
pub description: Option<String>,
}Expand description
A section within an entity (e.g. “Claim”, “Evidence”).
Fields
key: Stringheading: Stringrequired: boolsearch_weight: f32catch_all: boolwrite_rules: Vec<String>description: Option<String>Trait Implementations
Sourceimpl Clone for SectionDef
impl Clone for SectionDef
Sourcefn clone(&self) -> SectionDef
fn clone(&self) -> SectionDef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SectionDef
impl Debug for SectionDef
Sourceimpl<'de> Deserialize<'de> for SectionDef
impl<'de> Deserialize<'de> for SectionDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SectionDef
impl JsonSchema for SectionDef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SectionDef
impl RefUnwindSafe for SectionDef
impl Send for SectionDef
impl Sync for SectionDef
impl Unpin for SectionDef
impl UnsafeUnpin for SectionDef
impl UnwindSafe for SectionDef